%create_structure.m creates the matrices that constitute the structure of the SVAR  studied in the paper ``The Neo-Fisher Effect in the United States and Japan.'';
%The system in state-space form is 
%xi_t+1 = F xi_t + PSI eps_t
%o_t = A' + H'xi_t + mu_t
%E(PSI eps'ep'PSI') =PSI*PSI'= Q;
%E(mu,mu') = R;
%where xi_t is a vector of unobservable states, y_t is a vector of observables, and x_t is a vector of exogenous/predetermined variables (in the present model, x_t contains lagged values of Y_t), and e is an intercept. 
%Note P here is denoted \psi in the paper.
% Martn Uribe, May 2017. 


ny = 3; %# of latent endogenous variables 
nlags = 4; %# of lags 
nobs = 3; %number of observable variables
nshocks = 4;

RHO=zeros(nshocks);  %matrix of autoregressive coefficients of exogenous bloc
aux = (1:nshocks)'*[ 1 1 ];
aux_RHO = sub2ind(size(RHO),aux(:,1),aux(:,2));

P = zeros(nshocks);
aux = (1:nshocks)'*[ 1 1 ];
aux_P = sub2ind(size(P),aux(:,1),aux(:,2));

B = zeros(ny,ny*nlags); %matrix of autoregressive coefficients of endogenous bloc
aux_B = (1:nlags*ny*ny)';
aux_Bown = find(eye(ny));
aux_Bother = setdiff(aux_B,aux_Bown);

C = zeros(ny,nshocks);
%Introduce normalization C(3,2)=C(1,4)=1
aux = [3 2; 1 4];
aux_Ccomp = sub2ind(size(C),aux(:,1),aux(:,2));
C(aux_Ccomp) = 1;
aux_C = setdiff((1:numel(C))',aux_Ccomp);

Ap  = zeros(nobs,1);

R = zeros(nobs);
aux = [(1:nobs)'  (1:nobs)' ];
aux_R = sub2ind(size(R),aux(:,1),aux(:,2));

%Dy
Hp = zeros(nobs,ny*nlags+nshocks);
Hp(1,1) = 1;
Hp(1,ny+1) = -1;
Hp(1,ny*nlags+3) = 1;

%r
Hp(2,2) = -1;
Hp(2,3) = 1;

%Di
Hp(3,3) = 1;
Hp(3,ny+3) = -1;
Hp(3,ny*nlags+1) = 1;

%number of estimated parameters 
nRHO = numel(aux_RHO);
nP = numel(aux_P);
nB =  numel(aux_B);
nC = numel(aux_C);
nAp = numel(Ap);
nR =  numel(aux_R);
np = nRHO+nP+nB+nC+nAp +nR;

%Set of indices mapping elements of the vector collecting all of the estimated parameters to the estimated parameters of the specific matrices of the model, such as RHO, B, C, etc. 
n1=1;n2=nRHO; 
iRHO =(n1:n2)';
n1=n2+1;n2=n2+nP; 
iP = (n1:n2)'; 
n1=n2+1;n2=n2+nC; 
iC = (n1:n2)';
n1=n2+1;n2=n2+nB; 
iB = (n1:n2)';
n1=n2+1;n2=n2+nAp; 
iAp = (n1:n2)';
n1=n2+1;n2=n2+nR; 
iR = (n1:n2)';

iBown = iB(aux_Bown);
iBother = iB(aux_Bother);