function [y,theta,k, cumprob,xc] = dgamma(x,m,s,pc);
%y = dgamma(x,m,s) evaluates at x the 
%probability density function of the gamma 
%distribution with mean m and standard deviation  s.
%[y,theta,k] = dgamma(x,m,s) produces the 
%parameters defining the probability density 
%x^(k-1)*exp(-x/theta)/gamma(k)/(theta^k);
%%[y,a,b,cumprob] = dgamma(x,m,s) produces the value cumprob  representing the probability that a random viarialbe with gamma  distribution defined by the parameters a and b is less than or equal to x. 
%[y,a,b,cumprob,xc] = dgamma(x,m,s,pc) takes as input the value pc and produces the output xc such that the probability that a random variable with distribution gamma (a,b) be less than xc is pc. So, for example, if pc=0.5, then xc is themedian of the gamma  distribution


theta = s.^2 ./ m;
k = m ./ theta;

y = x.^(k-1).*exp(-x./theta)./gamma(k)./(theta.^k);
y(x<0) = 0;

if nargout>3
cumprob = gamcdf(x,k,theta);
cumprob(x<0) = 0;
end

if nargin>3 
xcH = 1e16;
xcL = 0;
pc0 = inf;
while abs(pc0 - pc)>1e-8
xc = (xcH+xcL)/2;
pc0 =   gamcdf(xc,k,theta);
if pc0 > pc
xcH = xc;
else xcL = xc;
end %if ans > pc
end  %while abs(pc0 - pc)>1e-8

else %if nargin>3
xc = [];
end; %if nargin >3
