function L = f(tryparam,Y,X)
%L = f(param,Y,X,T) evaluate the logarithm of the likelihood function, denoted L,  at the parameter vector param and data Y and X.  
%The system is of the form
%xi_t+1 = F *xi_t + PSI*eps_t+1
%y_t = Ap + Hp*xi_t + w_
%where xi_t is an unobservable state vector, eps_t is a vector of white noise, y_t is a vector of observable variables,   and w_t is a vector of measurement errors distributed N(0,R). 
%For the purpose of calculating the variance-covariance matrix of  impulse responses, it is not necessary to calculate the variance-covariance matrices  PSI,  R, and  Ap   since the IRs do not depend on these parameters. 
% Martn Uribe, May 2017. 

create_structure %create structure creates the structure of the basic  matrices that constitute the matrices F Q Ap Hp and R

evaluate_structure %evaluate_structure assigns values to the matrices of the SVAR

L =  log_like_kalman(Y,F,Q,transpose(Hp),R,X,transpose(Ap));

if ~isfinite(L) 
L = -inf;
end