function ir_chain
%ir_chain returns impulse responses with asymmetric error bands computed using  the method proposed by  Sims, Christopher A. and Tao Zha, ``Error Bands for Impulse Responses,'' Econometrica 67, September 1999, 1113-1155. 
%Notation:
%IR denotes impulse response, with the following  suffixes and prefixes: 
%mean mean implied by  the MCMC chain
%x and z permantnt and temporary interest-rate shock, respectively
%szb = 'Sims-Zha band, asymmetric version estimated separately for x and z'
%input: bayes.mat (produced by running bayes.m)
%output ir_chain.mat 
% Martn Uribe, July 2017. 

load bayes.mat param_chain RHO iRHO aux_RHO MPE np ny n ntrain nburn tar  %produced by running run_bayes.m

CL = 95; %confidence level 
N = size(param_chain,2); %length of MCMC chain
T = 21; %length of impulse response
I = 1e5;  %size of sample from MCMC chain

borders = round(I*[(1-CL/100)/2 (1+CL/100)/2]); %elements of the MCMC associated with the borders of the confidence band. 

Z = zeros(T*ny,I); %IRs to zm shock
X = zeros(T*ny,I); %IRs to xm shock
meanIRx = 0; 
meanIRz = 0;
varIRx = 0;
varIRz = 0;
varcovIRx = 0;
varcovIRz = 0;

nx = size(RHO,1); %# of shocks
x0 = zeros(nx,1);
x0(1) = 1; %this is used to compute the long-run value of the interest rate in response to a nonstationary monetary shock
LRi = 0;% long-run value of the interest rate in response to a nonstationary monetary shock. 

for n=1:I

x = randi(N);
param = param_chain(:,x);

shock = 1; %xm shock (permanent interest-rate increase)
 [y,pai,i,t,Dy,Dpai,Di] = ir_param(param,shock,T); %impulse respones of  y, pai, and i (levels of log output, inflation and interest rate); t is the time vector  [0 1 ... T-1]
IRx =[y pai i]; 
X(:,n) = IRx(:);

shock = 2; %zm shock (transitory increase  in the interest rate)
 [y,pai,i,t,Dy,Dpai,Di] = ir_param(param,shock,T);
IRz =[y pai i];
Z(:,n) = IRz(:);

meanIRx = meanIRx*(n-1)/n + IRx/n;
meanIRz = meanIRz*(n-1)/n + IRz/n;
varcovIRx = varcovIRx*(n-1)/n + IRx(:)*IRx(:)'/n;
varcovIRz = varcovIRz*(n-1)/n + IRz(:)*IRz(:)'/n;

%compute the average across draws of E_t X^m_t+j for j-->inft
RHO(aux_RHO) = param(iRHO); %Serial correlation matrix of exogenous shocks
(eye(nx)-RHO)\x0;
lri =  ans(1);
LRi = LRi * (n-1)/n + lri/n;

if mod(n,1000) == 0
disp(['n = ' num2str(n)])
end
end

varcovIRx = varcovIRx - meanIRx(:)*meanIRx(:)';
varcovIRz = varcovIRz - meanIRz(:)*meanIRz(:)';

%Sims-Zha  asymmetric 95% error bands X^m shock
[A,D] = eig(varcovIRx);
[d,id] = max(diag(D));
gx_chain =  sort(A(:,id)'*X-A(:,id)'*meanIRx(:));
gx = gx_chain(borders);
szbIRUx = zeros(T,ny); %Upper limit of band
szbIRUx(:) = max(A(:,id)*gx,[],2);
szbIRLx = zeros(T,ny); %Lwer limit of band
szbIRLx(:) = min(A(:,id)*gx,[],2);

%Asymmetric Sims-Zha 95% error bands (szb)
%zm shock (transitory increase in the interest-rate)
[A,D] = eig(varcovIRz);
[d,id] = max(diag(D));
gz_chain =  sort(A(:,id)'*Z-A(:,id)'*meanIRz(:));
gz = gz_chain(borders);
szbIRUz = zeros(T,ny);
szbIRUz(:) = max(A(:,id)*gz,[],2);
szbIRLz = zeros(T,ny);
szbIRLz(:) = min(A(:,id)*gz,[],2);

meanIRx = meanIRx / LRi;
szbIRLx = szbIRLx / LRi;
szbIRUx = szbIRUx / LRi;

save ir_chain.mat  meanIRx meanIRz  T szbIRLx szbIRUx szbIRLz szbIRUz N np n ntrain nburn tar  
