function [y,pai,i,t,Dy,Dpai,Di] = ir_param(param,shock,T);
%function [y,pai,i,t,Dy,Dpai,Di] = ir_param(param,shock,T) returns impulse  responses of the SVAR system developed in ``The Neo-Fisher Effect,'' by Martn Uribe with observables o_t = [Dy Dpai Dff], where y is the log of output, pai is inflation, and ff is the federal funds rate. 
%The state space representation of the system  is (ignoring a innovations and measurement-error term in the observation equation)
%z_t = B Z_t-1 + Cx_t 
%x_t+1 = RHO x_t
%where Z_t-1 = [z_t-1 z_t-2 z_t-3 z_t-4]
%o_t is a linear combination of z_t Z_t-1 and x_t
% Martn Uribe, 17-May-2017.

if nargin<3
T=21;
end

create_structure %create matrices of the SVAR system
tryparam = param;
evaluate_structure; %assign values to the matrices of the SVAR system

Dy = zeros(T,1);
Di = zeros(T,1);
Dpai = zeros(T,1);

nx = size(RHO,1); %number of shocks

%Initial conditions
x0 = zeros(nx,1);
x0(shock) = 1;
Z0 = zeros(ny*nlags,1);

for t=1:T
z = B*Z0 + C*x0;
Dy(t,1) = z(1)-Z0(1)+x0(3);
Dpai(t,1) = z(2)-Z0(2)+x0(1);
Di(t,1) = z(3)-Z0(3)+x0(1);

x0 = RHO*x0;
Z0 = [z;Z0(1:end-ny)];
end

y = cumsum(Dy);
i = cumsum(Di);
pai = cumsum(Dpai);

t = (0:T-1)';