function [IRx,IRz,IRUx,IRLx,IRUz,IRLz] = plot_ir_chain
%[IRx,IRz,IRUx,IRLx,IRUz,IRLz] = plot_ir_chain  returns and plots impulse responses to permanent and transitory 
%monetary shocks in the empirical model developed in  Uribe, Martn, ``The Neo-Fisher Effect: Econometric Evidence from 
%Empirical and Optimizing Models.'' The plots include asymmetric 95% error  bands computed using the method described by  
%Sims, Christopher A. and Tao Zha, ``Error Bands for Impulse Responses,'' Econometrica 67, September 1999, 1113-1155. 
%outputs:
%IRx,IRz point estimates  given by the mean implied by the MCMC chain. x refers to the permanent interest-rate shock and z to the temporary one. 
%IRUx,IRLx,IRUz,IRLz upper and lower borders of 95% error bands. 
% Martn Uribe, July 2017. 

clf

load ir_chain.mat %produced by running ir_chain.m

IRx = meanIRx;
IRz = meanIRz;

%Asymmetric 95% error bands estimated   
IRUx = IRx+szbIRUx;
IRLx = IRx+szbIRLx;
IRUz = IRz+szbIRUz;
IRLz = IRz+szbIRLz;

t = (0:T-1)'; %time horizon

color_line = 'b-';

%Permanent Interest-rate shock
%Response of the interest rate and Inflation 
subplot(2,2,1)
plot(t,IRx(:,3),'r--','linewidth',3)
hold on
%plot(t,IRLx(:,3),'r--' ,t,IRUx(:,3),'r--')
plot(t,IRx(:,2),color_line,'linewidth',3)
plot(t,IRLx(:,2),color_line,t,IRUx(:,2),color_line)
aux = ylim;
ylim([min(IRx(:,3)) aux(2)]);
legend('Interest Rate','Inflation', ' Inflation 95% band','location','southeast')
xlabel('quarters after the shock')
ylabel({'deviation from pre-shock level','percentage points  per year'})
title({'Permanent Interest-Rate Shock','Response of the Interest Rate and Inflation'})
grid


%Temporary Interest-rate shock
%Response of the interest rate and Inflation 
subplot(2,2,2)
plot(t,IRz(:,3),'r--','linewidth',3)
hold on
plot(t,IRz(:,2),color_line,'linewidth',3)
plot(t,IRLz(:,2),color_line,t,IRUz(:,2),color_line)
legend('Interest Rate','Inflation', ' Inflation 95% band','location','northeast')
xlabel('quarters after the shock')
ylabel({'deviation from pre-shock level','percentage points  per year'})
title({'Temporary Interest-Rate Shock','Response of the Interest Rate and Inflation'})
grid

%Permanent Interest-rate shock
%Response of Output
subplot(2,2,3)
plot(t,IRx(:,1),color_line,'linewidth',3),
hold on 
plot(t,IRLx(:,1),color_line,t,IRUx(:,1),color_line)
legend('Output', '95% band','location','northeast')
title({'Permanent Interest-Rate Shock','Response of Output'}) 
xlabel('quarters after the shock')
ylabel('percent deviation from pre-shock level')
grid

%Temporary Interest-rate shock
%Response of Output
subplot(2,2,4)
plot(t,IRz(:,1),color_line,'linewidth',3),
hold on 
plot(t,IRLz(:,1),color_line,t,IRUz(:,1),color_line)
legend('Output', '95% band','location','southeast')
title({'Temporary Interest-Rate Shock','Response of Output'}) 
xlabel('quarters after the shock')
ylabel('percent deviation from pre-shock level')
grid
shg