%plot_xm.m
%plots the inferred path of the nonstationary monetary shock Xm in the SVAr model of the paper ``The Neo-Fisher Effect in the United States and Japan,'' by Martn Uribe, 2017. 
% Martn Uribe, 03-Dec-2017.

clf, clear all

create_structure

load bayes.mat Y  date  mean_param X pai ff ; %produced by running run_bayes.m
tryparam = mean_param;
evaluate_structure

H = Hp';
A = Ap';
[XI_tT,P_tT,XI_tt,P_tt,XI_ttm1,P_ttm1] = smoothing_kalman(Y,F,Q,H,R,X,A);

xm = XI_tT(:,13); 
Xm = cumsum(xm);
Xm = Xm- mean(Xm) + mean(pai);

fsize = 12;
set(0,'defaulttextinterpreter','latex')
set(0, 'DefaultAxesFontSize', fsize)
set(0, 'DefaultTextFontSize', fsize) 
plot(date,Xm,'b','linewidth',3)
hold on
plot(date,pai,'r--','linewidth',3)
xlabel('year');
ylabel('$\%$ per year')
xlim([date(1) date(end)])
h=legend('$X^m_t$','Inflation')
set(h,'interpreter','latex')
grid
shg
