function [mxpar,mxlp] = probe;
%[mxpar,mxlp] = probe probe returns the vector mxpar that maximizes the log posterior likelihood. 
%It also returns mxlp, the value of the log posterior likelihood at mxpar. 
%mxpar and mxlp are  of use as a starting point for  estimation using Bayesian techniques. If priors are uniform, then mxpar is  the MLE parameter estimate. The model is the SVAR system developed in ``Fishing for the Neo-Fisher Effect,'' by Martn Uribe, with regressors [Dy pai-ff Dff]. 
% Martn Uribe, May 2017. 

warning off

rng('shuffle');
saverng = rng; %save  rand settings for replication 

%read data
[Dy,Dpai,Dff, y, pai,ff,date, readme_data] = read_data;
r = ff-pai;
Y = [Dy r Dff];
X = 0*Dy+1; %intercept
T = size(Y,1);
meanY = mean(Y)';
stdY = std(Y)';
varY = var(Y)';

create_structure; % creates the matrices that constitute the structure of the SVAR;

bounds %Lower and Upper bounds of uniform prior distributions of parameter vector

param0 = (LB+UB)/2;
param0(iBown) = 0.9;
param0(iBother) = 0;
mxpar = param0; 

mxl = f(param0,Y,X); %maximum value of log-likelihood function

prior = get_prior(param0,iB,iC,iRHO,iP,iAp,iR,meanY,varY,stdY,T,iBown,iBother);
mxlp = mxl +prior;

N = 1e6; %# of draws 

W = UB-LB;

n = 0; %# of draws completed
nprobe = 4; %number of  runs of this program used 
t1 = tic;
while n<N
tryparam = mxpar;
aux = randi(np);
tryparam(aux) = LB(aux) + rand*(UB(aux)-LB(aux)); 

evaluate_structure % assigns values to the matrices of the SVAR system

if unit_circle==1
try
likelihood =  log_like_kalman(Y,F,Q,Hp',R,X,Ap');
prior = get_prior(tryparam,iB,iC,iRHO,iP,iAp,iR,meanY,varY,stdY,T,iBown,iBother);
catch
likelihood = -inf;
end
else
likelihood = -inf;
end

if ~isreal(likelihood) | isnan(likelihood) | ~isfinite(likelihood)
likelihood = -inf;
end

posterior  = likelihood+prior;

if posterior>mxlp
mxl = likelihood; %maximum log-lihood 
mxpar = tryparam;
mxlp = posterior; %log-posterior likelihood

end %if logposterior>mxlp

n = n+1;
end %while n<N
