%vardecomp_chain returns variance decompositions  (posterior mean, and other posterior moments) predicted by the empirical model  developed  in Uribe, Martn, ``The Neo-Fisher Effect: Econometric Evidence from Empirical and Optimizing Models.''
%Notation:
%Vyr  is a matrix with containing the share of the variance of Dy Dpai Di (columns)  explained by shocks xm zm xn zn   (rows)
%so the sum across rows are all 1
%Vyr  appears with the  following  suffixes 
%mean: mean implied by  the MCMC chain
%std: standard deviations implied by  the MCMC chain
% Martn Uribe, May 2018. 

clear all

load  bayes.mat %produced by running run_bayes.m

nx = size(RHO,1); %# of shocks
CL = 95; %confidence level 
N = size(param_chain,2); %length of MCMC chain
I = 1e5;  %size of sample from MCMC chain

borders = round(I*[(1-CL/100)/2 (1+CL/100)/2]); %elements of the MCMC associated with the borders of the confidence band. 

X = zeros(nx*ny,I); %IRs to xm shock

for n=1:I

x = randi(N);
param = param_chain(:,x);

[Vyr,Vxr,Vy,Vx]=vardecomp(param);
X(:,n) = Vyr(:);

if mod(n,1000) == 0
disp(['n = ' num2str(n)])
end

end

%Express in table form: 
%rows: DXm, zm; DXn; zn
%columns Dy, Dpai; Di
meanVyr= zeros(nx,ny);
meanVyr(:) = mean(X,2);

stdVyr=zeros(nx,ny);
stdVyr(:) = std(X')';

save vardecomp_chain.mat meanVyr stdVyr
